@@ -33,9 +33,10 @@
 #  define KWAYLANDSERVER_DEPRECATED_NO_EXPORT KWAYLANDSERVER_NO_EXPORT KWAYLANDSERVER_DEPRECATED
 #endif
 
-#define DEFINE_NO_DEPRECATED 0
-#if DEFINE_NO_DEPRECATED
-# define KWAYLANDSERVER_NO_DEPRECATED
+#if 0 /* DEFINE_NO_DEPRECATED */
+#  ifndef KWAYLANDSERVER_NO_DEPRECATED
+#    define KWAYLANDSERVER_NO_DEPRECATED
+#  endif
 #endif
 
 #endif
